@@ -508,14 +508,7 @@ class StateForActualGivenExecution(object):
 
         self.used_examples_from_database = False
 
-    def execute(
-        self,
-        data,
-        print_example=False,
-        is_final=False,
-        expected_failure=None,
-        collect=False,
-    ):
+    def execute(self, data, print_example=False, is_final=False, expected_failure=None):
         text_repr = [None]
         if self.settings.deadline is None:
             test = self.test
@@ -811,10 +804,6 @@ def given(
     """
 
     def run_test_with_generator(test):
-        if hasattr(test, "_hypothesis_internal_test_function_without_warning"):
-            # Pull out the original test function to avoid the warning we
-            # stuck in about using @settings without @given.
-            test = test._hypothesis_internal_test_function_without_warning
         if inspect.isclass(test):
             # Provide a meaningful error to users, instead of exceptions from
             # internals that assume we're dealing with a function.
@@ -967,10 +956,10 @@ def given(
                 if isinstance(runner, TestCase) and hasattr(runner, "subTest"):
                     subTest = runner.subTest
                     try:
-                        setattr(runner, "subTest", fake_subTest)
+                        runner.subTest = fake_subTest
                         state.run()
                     finally:
-                        setattr(runner, "subTest", subTest)
+                        runner.subTest = subTest
                 else:
                     state.run()
             except BaseException as e:
